#
# spec file for package ocaml-parmap
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ocaml-parmap
Version:        1.2.5
Release:        2.5
%{?ocaml_preserve_bytecode}
Summary:        Multicore architecture exploitation for OCaml programs with minimal modifications
License:        LGPL-2.0-only
Group:          Development/Languages/OCaml
URL:            https://opam.ocaml.org/packages/parmap
Source0:        %name-%version.tar.xz
BuildRequires:  ocaml
BuildRequires:  ocaml-dune >= 2.7
BuildRequires:  ocaml-rpm-macros >= 20231101
BuildRequires:  ocamlfind(bigarray)
BuildRequires:  ocamlfind(dune-configurator)
BuildRequires:  ocamlfind(graphics)
BuildRequires:  ocamlfind(unix)
BuildRequires:  pkgconfig(x11)

%description
If you want to use your many cores to accelerate an operation
which happens to be a map, fold or map/fold (map-reduce), just use
Parmap's parmap, parfold and parmapfold primitives in place of the
standard List.map and friends; you can specify the number of
subprocesses to use with the optional parameter ncores, and the
size of granularity of the parallel computation with the optional
parameter chunksize.

%package        devel
Summary:        Development files for %name
Group:          Development/Languages/OCaml
Requires:       %name = %version

%description    devel
The %name-devel package contains libraries and signature files for
developing applications that use %name.


%prep
%autosetup -p1

%build
sed -i~ '
s@10000000@1000000@
' tests/simplescale.ml
diff -u "$_"~ "$_" && exit 1
dune_release_pkgs='parmap'
%ocaml_dune_setup
%ocaml_dune_build

%install
%ocaml_dune_install
%ocaml_create_file_list

%check
OCAML_DUNE_RUNTEST_ARGS="-j 1"
export nData=$((1000 * 10))
export nProcs=2
%ocaml_dune_test

%files -f %name.files

%files devel -f %name.files.devel

%changelog
* Tue Jan 16 2024 ohering@suse.de
- Remove usage of dune.configurator because ocamlfind names which
  contain a dot are not considered valid anymore with dune 3.13
* Sun Jan  1 2023 ohering@suse.de
- Update to version 1.2.5
  Add support for OCaml 5.0
* Mon Apr  4 2022 ohering@suse.de
- Update to version 1.2.4
  fix naked pointers
* Sun May  2 2021 ohering@suse.de
- Update to version 1.2.3
  follow upstream versioning
* Sun Apr 25 2021 ohering@suse.de
- Update to version 20210423.2800b78
  avoid corruption on 32bit architectures
  add support for returning results in the right order
* Thu Feb 20 2020 ohering@suse.de
- Require current ocaml-rpm-macros
- Update to version 20200124.526acc4 (1.1.1)
  merged our changes for dune and recent ocaml versions
* Fri Nov  1 2019 ohering@suse.de
- Require current dune macros
- Update to 20191021.1b17a5d from dune branch
* Wed Oct  9 2019 ohering@suse.de
- Update to version 20191002.803edbb (1.0-rc11)
* Tue Oct  1 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Mon Sep 23 2019 ohering@suse.de
- Update to version 20190330.8d19c66
  Fix for ocaml 4.06
* Tue Jul 25 2017 ohering@suse.de
- Use Group: Development/Languages/OCaml
* Mon Jul 17 2017 ohering@suse.de
- Update to version 20170223.c9b0ee7
  Only wait for the children started by parmap
  Prevent at_exit handlers registered in the parent from running in the child
  handle EINTR errors in wait_for_pids
  added get_ncores
  Gc.compact needs to be called only inside of spawn_many
  added get_rank so that worker processes can know at which rank they were forked out of the master process
* Mon Jul 17 2017 ohering@suse.de
- Wrap specfile conditionals to fix quilt setup
* Mon Jul 17 2017 ohering@suse.de
- Remove autodeps for pre openSUSE 12.1 releases
* Wed May 31 2017 olaf@aepfle.de
- Replace tabs with spaces in generated _oasis file
* Sat Jun  4 2016 jeffm@suse.com
- Handle racing mkdirs
* Tue May 24 2016 olaf@aepfle.de
- Initial version 20160512.7598fb9 for coccinelle
